==> aedev_tpl_app-0.0.1.tar.gz: aedev_tpl_app-0.0.1/README.md <==
<!-- THIS FILE IS EXCLUSIVELY MAINTAINED by the project aedev V0.3.9 -->
<!-- THIS FILE IS EXCLUSIVELY MAINTAINED by the project aedev_tpl_namespace_root V0.3.5 -->
# tpl_app 0.0.1

[![GitLab develop](https://img.shields.io/gitlab/pipeline/aedev-group/aedev_tpl_app/develop?logo=python)](
    https://gitlab.com/aedev-group/aedev_tpl_app)
[![LatestPyPIrelease](
    https://img.shields.io/gitlab/pipeline/aedev-group/aedev_tpl_app/releasenone?logo=python)](
    https://gitlab.com/aedev-group/aedev_tpl_app/-/tree/releasenone)
[![PyPIVersions](https://img.shields.io/pypi/v/aedev_tpl_app)](
    https://pypi.org/project/aedev-tpl-app/#history)

>aedev namespace module portion tpl_app: aedev_tpl_add module main module.

[![Coverage](aedev-group.gitlab.io/aedev_tpl_app/coverage.svg)](
    aedev-group.gitlab.io/aedev_tpl_app/coverage/index.html)
[![MyPyPrecision](aedev-group.gitlab.io/aedev_tpl_app/mypy.svg)](
    aedev-group.gitlab.io/aedev_tpl_app/lineprecision.txt)
[![PyLintScore](aedev-group.gitlab.io/aedev_tpl_app/pylint.svg)](
    aedev-group.gitlab.io/aedev_tpl_app/pylint.log)

[![PyPIImplementation](https://img.shields.io/pypi/implementation/aedev_tpl_app)](
    https://gitlab.com/aedev-group/aedev_tpl_app/)
[![PyPIPyVersions](https://img.shields.io/pypi/pyversions/aedev_tpl_app)](
    https://gitlab.com/aedev-group/aedev_tpl_app/)
[![PyPIWheel](https://img.shields.io/pypi/wheel/aedev_tpl_app)](
    https://gitlab.com/aedev-group/aedev_tpl_app/)
[![PyPIFormat](https://img.shields.io/pypi/format/aedev_tpl_app)](
    https://pypi.org/project/aedev-tpl-app/)
[![PyPILicense](https://img.shields.io/pypi/l/aedev_tpl_app)](
    https://gitlab.com/aedev-group/aedev_tpl_app/-/blob/develop/LICENSE.md)
[![PyPIStatus](https://img.shields.io/pypi/status/aedev_tpl_app)](
    https://libraries.io/pypi/aedev-tpl-app)
[![PyPIDownloads](https://img.shields.io/pypi/dm/aedev_tpl_app)](
    https://pypi.org/project/aedev-tpl-app/#files)


## installation


execute the following command to install the
aedev.tpl_app module
in the currently active virtual environment:
 
```shell script
pip install aedev-tpl-app
```

if you want to contribute to this portion then first fork
[the aedev_tpl_app repository at GitLab](
https://gitlab.com/aedev-group/aedev_tpl_app "aedev.tpl_app code repository").
after that pull it to your machine and finally execute the
following command in the root folder of this repository
(aedev_tpl_app):

```shell script
pip install -e .[dev]
```

the last command will install this module portion, along with the tools you need
to develop and run tests or to extend the portion documentation. to contribute only to the unit tests or to the
documentation of this portion, replace the setup extras key `dev` in the above command with `tests` or `docs`
respectively.

more detailed explanations on how to contribute to this project
[are available here](
https://gitlab.com/aedev-group/aedev_tpl_app/-/blob/develop/CONTRIBUTING.rst)


## namespace portion documentation

information on the features and usage of this portion are available at
[ReadTheDocs](
https://aedev.readthedocs.io/en/latest/_autosummary/aedev.tpl_app.html#module-aedev.tpl_app
"aedev_tpl_app documentation").

==> aedev_tpl_app-0.3.4.tar.gz: aedev_tpl_app-0.3.4/README.md <==
<!-- THIS FILE IS EXCLUSIVELY MAINTAINED by the project aedev.aedev V0.3.14 -->
<!-- THIS FILE IS EXCLUSIVELY MAINTAINED by the project aedev.tpl_namespace_root V0.3.10 -->
# tpl_app 0.3.4

[![GitLab develop](https://img.shields.io/gitlab/pipeline/aedev-group/aedev_tpl_app/develop?logo=python)](
    https://gitlab.com/aedev-group/aedev_tpl_app)
[![LatestPyPIrelease](
    https://img.shields.io/gitlab/pipeline/aedev-group/aedev_tpl_app/release0.3.3?logo=python)](
    https://gitlab.com/aedev-group/aedev_tpl_app/-/tree/release0.3.3)
[![PyPIVersions](https://img.shields.io/pypi/v/aedev_tpl_app)](
    https://pypi.org/project/aedev-tpl-app/#history)

>aedev namespace package portion tpl_app: aedev_tpl_add module main module.

[![Coverage](https://aedev-group.gitlab.io/aedev_tpl_app/coverage.svg)](
    https://aedev-group.gitlab.io/aedev_tpl_app/coverage/index.html)
[![MyPyPrecision](https://aedev-group.gitlab.io/aedev_tpl_app/mypy.svg)](
    https://aedev-group.gitlab.io/aedev_tpl_app/lineprecision.txt)
[![PyLintScore](https://aedev-group.gitlab.io/aedev_tpl_app/pylint.svg)](
    https://aedev-group.gitlab.io/aedev_tpl_app/pylint.log)

[![PyPIImplementation](https://img.shields.io/pypi/implementation/aedev_tpl_app)](
    https://gitlab.com/aedev-group/aedev_tpl_app/)
[![PyPIPyVersions](https://img.shields.io/pypi/pyversions/aedev_tpl_app)](
    https://gitlab.com/aedev-group/aedev_tpl_app/)
[![PyPIWheel](https://img.shields.io/pypi/wheel/aedev_tpl_app)](
    https://gitlab.com/aedev-group/aedev_tpl_app/)
[![PyPIFormat](https://img.shields.io/pypi/format/aedev_tpl_app)](
    https://pypi.org/project/aedev-tpl-app/)
[![PyPILicense](https://img.shields.io/pypi/l/aedev_tpl_app)](
    https://gitlab.com/aedev-group/aedev_tpl_app/-/blob/develop/LICENSE.md)
[![PyPIStatus](https://img.shields.io/pypi/status/aedev_tpl_app)](
    https://libraries.io/pypi/aedev-tpl-app)
[![PyPIDownloads](https://img.shields.io/pypi/dm/aedev_tpl_app)](
    https://pypi.org/project/aedev-tpl-app/#files)


## installation


execute the following command to install the
aedev.tpl_app package
in the currently active virtual environment:
 
```shell script
pip install aedev-tpl-app
```

if you want to contribute to this portion then first fork
[the aedev_tpl_app repository at GitLab](
https://gitlab.com/aedev-group/aedev_tpl_app "aedev.tpl_app code repository").
after that pull it to your machine and finally execute the
following command in the root folder of this repository
(aedev_tpl_app):

```shell script
pip install -e .[dev]
```

the last command will install this package portion, along with the tools you need
to develop and run tests or to extend the portion documentation. to contribute only to the unit tests or to the
documentation of this portion, replace the setup extras key `dev` in the above command with `tests` or `docs`
respectively.

more detailed explanations on how to contribute to this project
[are available here](
https://gitlab.com/aedev-group/aedev_tpl_app/-/blob/develop/CONTRIBUTING.rst)


## namespace portion documentation

information on the features and usage of this portion are available at
[ReadTheDocs](
https://aedev.readthedocs.io/en/latest/_autosummary/aedev.tpl_app.html
"aedev_tpl_app documentation").
